@@ -109,12 +109,11 @@
 #ifndef _CST_VAL_CONSTS_H__
 #define _CST_VAL_CONSTS_H__
 
-#include <stdio.h>
 #include "cst_val_defs.h"
 
-/* There is built-in int to string conversions here for numbers  */
-/* up to 20, not if you make this bigger you have to hand change */
-/* other things too                                              */
+/* There is built-in int to string conversions here for numbers   */
+/* up to 20, note if you make this bigger you have to hand change */
+/* other things too                                               */
 #define CST_CONST_INT_MAX 19
 
 #ifndef NO_UNION_INITIALIZATION
@@ -124,7 +123,7 @@
 #define DEF_CONST_VAL_INT(N,V) const cst_val N = {{.a={.type=CST_VAL_TYPE_INT,.ref_count=-1,.v={.ival=V}}}}
 #define DEF_CONST_VAL_STRING(N,S) const cst_val N = {{.a={.type=CST_VAL_TYPE_STRING,.ref_count=-1,.v={.vval= (void *)S}}}}
 #define DEF_CONST_VAL_FLOAT(N,F) const cst_val N = {{.a={.type=CST_VAL_TYPE_FLOAT,.ref_count=-1,.v={.fval=F}}}}
-#define DEF_CONST_VAL_CONS(N,A,D) const cst_val N = {{.cc={.car=A,.cdr=D }}}
+#define DEF_CONST_VAL_CONS(N,A,D) const cst_val N = {{.cc={.car=(cst_val *)A,.cdr=(cst_val *)D }}}
 
 extern const cst_val val_int_0; 
 extern const cst_val val_int_1; 
@@ -146,6 +145,11 @@ extern const cst_val val_int_16;
 extern const cst_val val_int_17;
 extern const cst_val val_int_18;
 extern const cst_val val_int_19;
+extern const cst_val val_int_20;
+extern const cst_val val_int_21;
+extern const cst_val val_int_22;
+extern const cst_val val_int_23;
+extern const cst_val val_int_24;
 
 extern const cst_val val_string_0; 
 extern const cst_val val_string_1; 
@@ -167,6 +171,11 @@ extern const cst_val val_string_16;
 extern const cst_val val_string_17;
 extern const cst_val val_string_18;
 extern const cst_val val_string_19;
+extern const cst_val val_string_20;
+extern const cst_val val_string_21;
+extern const cst_val val_string_22;
+extern const cst_val val_string_23;
+extern const cst_val val_string_24;
 
 #else
 /* Only GCC seems to currently support the C99 standard for giving      */
@@ -174,41 +183,64 @@ extern const cst_val val_string_19;
 /* things to be const, and to be small structures this is really useful */
 /* thus for compilers not supporting no_union_initization we use other  */
 /* structure that we know (hope ?) are the same size and use agressive  */
-/* casting. The goal here is wholly justified by the method here isn't  */
+/* casting. The goal here is wholly justified but the method here isn't */
 /* pretty                                                               */
 
 /* These structures are defined *solely* to get round initialization    */
-/* problems if you need to use these in any code you are using your are */
+/* problems if you need to use these in any code you are using, you are */
 /* unquestionably doing the wrong thing                                 */
 typedef struct cst_val_atom_struct_float {
 #ifdef WORDS_BIGENDIAN
     short ref_count;
     short type;  /* order is here important */
+#else
+#if (defined(__x86_64__) || defined(_M_X64))
+    int type;  /* order is here important */
+    int ref_count;
 #else
     short type;  /* order is here important */
     short ref_count;
 #endif
+#endif
+#if (defined(__x86_64__) || defined(_M_X64))
+    double fval;
+#else
     float fval;
+#endif
 } cst_val_float;
 
 typedef struct cst_val_atom_struct_int {
 #ifdef WORDS_BIGENDIAN
     short ref_count;
     short type;  /* order is here important (and unintuitive) */
+#else
+#if (defined(__x86_64__) || defined(_M_X64))
+    int type;  /* order is here important */
+    int ref_count;
 #else
     short type;  /* order is here important */
     short ref_count;
 #endif
+#endif
+#if (defined(__x86_64__) || defined(_M_X64))
+    long long ival;
+#else
     int ival;
+#endif
 } cst_val_int;
 
 typedef struct cst_val_atom_struct_void {
 #ifdef WORDS_BIGENDIAN
     short ref_count;
     short type;  /* order is here important */
+#else
+#if (defined(__x86_64__) || defined(_M_X64))
+    int type;  /* order is here important */
+    int ref_count;
 #else
     short type;  /* order is here important */
     short ref_count;
+#endif
 #endif
     void *vval;
 } cst_val_void;
@@ -246,6 +278,11 @@ extern const cst_val_int val_int_16;
 extern const cst_val_int val_int_17;
 extern const cst_val_int val_int_18;
 extern const cst_val_int val_int_19;
+extern const cst_val_int val_int_20;
+extern const cst_val_int val_int_21;
+extern const cst_val_int val_int_22;
+extern const cst_val_int val_int_23;
+extern const cst_val_int val_int_24;
 
 extern const cst_val_void val_string_0; 
 extern const cst_val_void val_string_1; 
@@ -267,6 +304,11 @@ extern const cst_val_void val_string_16;
 extern const cst_val_void val_string_17;
 extern const cst_val_void val_string_18;
 extern const cst_val_void val_string_19;
+extern const cst_val_void val_string_20;
+extern const cst_val_void val_string_21;
+extern const cst_val_void val_string_22;
+extern const cst_val_void val_string_23;
+extern const cst_val_void val_string_24;
 
 #endif
 
@@ -299,6 +341,11 @@ extern const cst_val_void val_string_19;
 #define VAL_INT_17 (cst_val *)&val_int_17
 #define VAL_INT_18 (cst_val *)&val_int_18
 #define VAL_INT_19 (cst_val *)&val_int_19
+#define VAL_INT_20 (cst_val *)&val_int_20
+#define VAL_INT_21 (cst_val *)&val_int_21
+#define VAL_INT_22 (cst_val *)&val_int_22
+#define VAL_INT_23 (cst_val *)&val_int_23
+#define VAL_INT_24 (cst_val *)&val_int_24
 
 const cst_val *val_int_n(int n);
 
@@ -322,6 +369,11 @@ const cst_val *val_int_n(int n);
 #define VAL_STRING_17 (cst_val *)&val_string_17
 #define VAL_STRING_18 (cst_val *)&val_string_18
 #define VAL_STRING_19 (cst_val *)&val_string_19
+#define VAL_STRING_20 (cst_val *)&val_string_20
+#define VAL_STRING_21 (cst_val *)&val_string_21
+#define VAL_STRING_22 (cst_val *)&val_string_22
+#define VAL_STRING_23 (cst_val *)&val_string_23
+#define VAL_STRING_24 (cst_val *)&val_string_24
 
 const cst_val *val_string_n(int n);
 
